==> scikit-surgerybk-0.3.4.tar.gz: scikit-surgerybk-0.3.4/setup.py <==
# coding=utf-8
"""
Setup for scikit-surgerybk
"""

from setuptools import setup, find_packages
import versioneer

# Get the long description
with open('README.rst') as f:
    long_description = f.read()

setup(
    name='scikit-surgerybk',
    version=versioneer.get_version(),
    cmdclass=versioneer.get_cmdclass(),
    description='Python package for interfacing with BK Ultrasound machines',
    long_description=long_description,
    long_description_content_type='text/x-rst',
    url='https://github.com/UCL/scikit-surgerybk',
    author='Thomas Dowrick',
    author_email='YOUR-EMAIL@ucl.ac.uk',
    license='BSD-3 license',
    classifiers=[
        'Development Status :: 3 - Alpha',

        'Intended Audience :: Developers',
        'Intended Audience :: Healthcare Industry',
        'Intended Audience :: Information Technology',
        'Intended Audience :: Science/Research',


        'License :: OSI Approved :: BSD License',


        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 3',

        'Topic :: Scientific/Engineering :: Information Analysis',
        'Topic :: Scientific/Engineering :: Medical Science Apps.',
    ],

    keywords='medical imaging',

    packages=find_packages(
        exclude=[
            'doc',
            'tests',
        ]
    ),

    install_requires=[
        'six>=1.10',
        #'numpy>=1.8',
    ],

    entry_points={
        'console_scripts': [
            'sksurgerybk=sksurgerybk.__main__:main',
        ],
    },
)

==> scikit-surgerybk-0.3.5.tar.gz: scikit-surgerybk-0.3.5/setup.py <==
# coding=utf-8
"""
Setup for scikit-surgerybk
"""

from setuptools import setup, find_packages
import versioneer

# Get the long description
with open('README.rst') as f:
    long_description = f.read()

setup(
    name='scikit-surgerybk',
    version=versioneer.get_version(),
    cmdclass=versioneer.get_cmdclass(),
    description='Python package for interfacing with BK Ultrasound machines',
    long_description=long_description,
    long_description_content_type='text/x-rst',
    url='https://github.com/SciKit-Surgery/scikit-surgerybk',
    author='Thomas Dowrick',
    author_email='YOUR-EMAIL@ucl.ac.uk',
    license='BSD-3 license',
    classifiers=[
        'Development Status :: 3 - Alpha',

        'Intended Audience :: Developers',
        'Intended Audience :: Healthcare Industry',
        'Intended Audience :: Information Technology',
        'Intended Audience :: Science/Research',


        'License :: OSI Approved :: BSD License',


        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 3',

        'Topic :: Scientific/Engineering :: Information Analysis',
        'Topic :: Scientific/Engineering :: Medical Science Apps.',
    ],

    keywords='medical imaging',

    packages=find_packages(
        exclude=[
            'doc',
            'tests',
        ]
    ),

    install_requires=[
        'six>=1.10',
        #'numpy>=1.8',
    ],

    entry_points={
        'console_scripts': [
            'sksurgerybk=sksurgerybk.__main__:main',
        ],
    },
)
